@@ -1,9 +1,8 @@
-#sweep test!
+import RobotArm
 from RobotArm import network
 import math
 import time
 
-
 class Robot:
     
 
